@@ -1,5 +1,5 @@
 package Anki::Import ;
-$Anki::Import::VERSION = '0.007';
+$Anki::Import::VERSION = '0.008';
 use strict;
 use warnings;
 use Cwd;
@@ -268,7 +268,7 @@ Anki::Import - Anki note generation made easy.
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 OVERVIEW
 
@@ -555,6 +555,11 @@ L<https://github.com/sdondley/Anki-Import>
 
   git clone git://github.com/sdondley/Anki-Import.git
 
+=head1 BUGS AND LIMITATIONS
+
+You can make new bug reports, and view existing ones, through the
+web interface at L<https://github.com/sdondley/Anki-Import/issues>.
+
 =head1 SEE ALSO
 
 L<Anki documentation|https://apps.ankiweb.net/docs/manual.html>
